@@ -116,7 +116,7 @@
 #' @param ctor_pkg String-valued package name when passing a string-valued
 #'   constructor name or `NULL`
 #' @param dat_valid (Optional) input data validator
-#' @param name Block name
+#' @param block_name Block name
 #' @param allow_empty_state Either `TRUE`, `FALSE` or a character vector of
 #' `state` values that may be empty while still moving forward with block eval
 #' @param ... Further (metadata) attributes
@@ -136,7 +136,7 @@
 #'       )
 #'     },
 #'     function(id) {
-#'       tagList()
+#'       htmltools::tagList()
 #'     },
 #'     class = "identity_block"
 #'   )
@@ -153,8 +153,9 @@
 #' inherits from `blocks` or not.
 #'
 #' @export
-new_block <- function(server, ui, class, ctor, ctor_pkg, dat_valid = NULL,
-                      allow_empty_state = FALSE, name = NULL, ...) {
+new_block <- function(server, ui, class, ctor = sys.parent(), ctor_pkg = NULL,
+                      dat_valid = NULL, allow_empty_state = FALSE,
+                      block_name = default_block_name, ...) {
 
   stopifnot(is.character(class), length(class) > 0L)
 
@@ -164,63 +165,17 @@ new_block <- function(server, ui, class, ctor, ctor_pkg, dat_valid = NULL,
     }
   }
 
-  if (missing(ctor)) {
-    ctor <- sys.parent()
+  if (is.null(block_name)) {
+    block_name <- default_block_name
   }
 
-  if (is.numeric(ctor)) {
+  class <- c(class, "block")
 
-    fun <- sys.function(ctor)
-    call <- deparse(sys.call(ctor)[[1L]])
-
-    if (grepl("::", call, fixed = TRUE)) {
-
-      call <- strsplit(call, "::", fixed = TRUE)[[1L]]
-
-      stopifnot(length(call) == 2L)
-
-      ctor <- call[2L]
-
-      if (missing(ctor_pkg)) {
-        ctor_pkg <- call[1L]
-      } else {
-        stopifnot(identical(ctor_pkg, call[1L]))
-      }
-
-    } else {
-
-      if (missing(ctor_pkg)) {
-        ctor_pkg <- pkg_name(environment(fun))
-      }
-
-      if (not_null(ctor_pkg)) {
-        ctor <- call
-      }
-    }
-
-    if (is_string(ctor_pkg) && is_string(ctor)) {
-      try <- get0(ctor, asNamespace(ctor_pkg), mode = "function",
-                  inherits = FALSE)
-    } else {
-      try <- NULL
-    }
-
-    if (is.null(try)) {
-      ctor <- fun
-      ctor_pkg <- NULL
-    }
+  if (is.function(block_name)) {
+    block_name <- block_name(class)
   }
 
-  if (is.null(ctor_pkg)) {
-    stopifnot(is.function(ctor))
-  } else {
-    stopifnot(is_string(ctor), is_string(ctor_pkg))
-  }
-
-  if (is.null(name)) {
-    name <- gsub("_", " ", class[1L])
-    name <- paste0(toupper(substr(name, 1L, 1L)), substring(name, 2L))
-  }
+  stopifnot(is_string(block_name))
 
   validate_block(
     new_vctr(
@@ -230,20 +185,26 @@ new_block <- function(server, ui, class, ctor, ctor_pkg, dat_valid = NULL,
         dat_valid = dat_valid
       ),
       ...,
-      ctor = ctor,
-      ctor_pkg = ctor_pkg,
-      name = name,
+      ctor = resolve_ctor(ctor, ctor_pkg),
+      name = block_name,
       allow_empty_state = allow_empty_state,
-      class = c(class, "block")
+      class = class
     ),
     ui_eval = TRUE
   )
 }
 
+#' @rdname new_block
+#' @export
+default_block_name <- function(class) {
+  res <- gsub("_", " ", sub("_block$", "", class[1L]))
+  paste0(toupper(substr(res, 1L, 1L)), substring(res, 2L))
+}
+
 validate_block_server <- function(server) {
 
   if (!is.function(server)) {
-    abort(
+    blockr_abort(
       "A block server component is expected to be a function.",
       class = "block_server_function_invalid"
     )
@@ -252,31 +213,25 @@ validate_block_server <- function(server) {
   args <- names(formals(server))
 
   if (!identical(args[1L], "id")) {
-    abort(
-      paste(
-        "A block server function is expected to have an argument `id` in",
-        "first poistion."
-      ),
+    blockr_abort(
+      "A block server function is expected to have an argument `id` in ",
+      "first postion.",
       class = "block_server_arg_id_invalid"
     )
   }
 
   if ("..." %in% args) {
-    abort(
-      paste(
-        "Variadic blocks are supported not by passing arguments as `...`",
-        "but using a special argument `...args`."
-      ),
+    blockr_abort(
+      "Variadic blocks are supported not by passing arguments as `...` ",
+      "but using a special argument `...args`.",
       class = "block_server_dots_invalid"
     )
   }
 
   if (any(grepl("^[1-9][0-9]*$", args))) {
-    abort(
-      paste(
-        "Integer-valued argument names are reserved as poistional arguments",
-        "in `...args.`"
-      ),
+    blockr_abort(
+      "Integer-valued argument names are reserved as poistional arguments ",
+      "in `...args.`",
       class = "block_server_args_invalid"
     )
   }
@@ -287,14 +242,14 @@ validate_block_server <- function(server) {
 validate_block_ui <- function(ui) {
 
   if (!is.function(ui)) {
-    abort(
+    blockr_abort(
       "A block UI component is expected to be a function.",
       class = "block_ui_function_invalid"
     )
   }
 
   if (!identical(names(formals(ui)), "id")) {
-    abort(
+    blockr_abort(
       "A block UI function is expected to have a single argument `id`.",
       class = "block_ui_arg_id_invalid"
     )
@@ -308,7 +263,7 @@ validate_data_validator <- function(validator, server) {
   server_args <- setdiff(names(formals(server)), "id")
 
   if (!length(server_args) && not_null(validator)) {
-    abort(
+    blockr_abort(
       "A nullary server function cannot accopmany a data input validator.",
       class = "block_validator_nullary_invalid"
     )
@@ -317,7 +272,7 @@ validate_data_validator <- function(validator, server) {
   if (not_null(validator)) {
 
     if (!is.function(validator)) {
-      abort(
+      blockr_abort(
         "Data input validator is expected to be a function.",
         class = "block_validator_function_invalid"
       )
@@ -326,11 +281,8 @@ validate_data_validator <- function(validator, server) {
     val_args <- names(formals(validator))
 
     if (!identical(server_args, val_args)) {
-      abort(
-        paste0(
-          "Server args ", paste_enum(server_args), " do not match validator ",
-          "args ", paste_enum(val_args), "."
-        ),
+      blockr_abort(
+        "Server args {server_args} do not match validator args {val_args}.",
         class = "block_validator_args_invalid"
       )
     }
@@ -342,35 +294,37 @@ validate_data_validator <- function(validator, server) {
 validate_block <- function(x, ui_eval = FALSE) {
 
   if (!is_block(x)) {
-    abort(
+    blockr_abort(
       "Expecting blocks to inherit from \"block\".",
       class = "block_class_invalid"
     )
   }
 
   if (class(x)[1L] == "block") {
-    abort(
+    blockr_abort(
       "Expecting blocks to have at least one sub-class.",
       class = "block_class_invalid"
     )
   }
 
   if (!is.list(x)) {
-    abort(
+    blockr_abort(
       "Expecting blocks to behave list-like.",
       class = "block_list_like_invalid"
     )
   }
 
-  if (!is.function(try(block_ctor(x), silent = TRUE))) {
-    abort(
-      "Cannot reconstruct blocks without constructors.",
-      class = "block_no_ctor"
+  ctor <- block_ctor(x)
+
+  if (!is_blockr_ctor(ctor)) {
+    blockr_abort(
+      "Expecting a block constructor to inherit from `blockr_ctor`.",
+      class = "block_ctor_invalid"
     )
   }
 
   if (!is_string(block_name(x))) {
-    abort(
+    blockr_abort(
       "Expecting a string-valued block name.",
       class = "block_name_invalid"
     )
@@ -387,11 +341,9 @@ validate_block <- function(x, ui_eval = FALSE) {
     ui <- expr_ui("block", x)
 
     if (!inherits(ui, "shiny.tag", "shiny.tag.list", agg = any)) {
-      abort(
-        paste(
-          "A block UI function is expected to return a shiny UI object,",
-          "i.e. either a `shiny.tag` or a `shiny.tag.list`."
-        ),
+      blockr_abort(
+        "A block UI function is expected to return a shiny UI object, i.e. ",
+        "either a `shiny.tag` or a `shiny.tag.list`.",
         class = "block_ui_eval_invalid"
       )
     }
@@ -418,66 +370,6 @@ as_block.block <- function(x, ...) {
   validate_block(x)
 }
 
-#' @export
-as_block.list <- function(x, ...) {
-
-  stopifnot(
-    all(c("constructor", "payload", "package", "object") %in% names(x))
-  )
-
-  ctor <- get(
-    x[["constructor"]],
-    asNamespace(x[["package"]]),
-    mode = "function"
-  )
-
-  args <- setdiff(names(formals(ctor)), "...")
-
-  args <- c(
-    x[["payload"]][args],
-    ctor = x[["constructor"]],
-    ctor_pkg = x[["package"]]
-  )
-
-  res <- do.call(ctor, args)
-
-  if (!identical(class(res), x[["object"]])) {
-    stop("Could not deserialize block.")
-  }
-
-  res
-}
-
-#' @export
-as.list.block <- function(x, state = NULL, ...) {
-
-  pkg <- attr(x, "ctor_pkg")
-
-  if (is.null(state)) {
-    state <- initial_block_state(x)
-  }
-
-  attrs <- attributes(x)
-
-  state <- c(
-    state,
-    attrs[
-      setdiff(
-        names(attrs),
-        c("names", "ctor", "ctor_pkg", "class", "allow_empty_state")
-      )
-    ]
-  )
-
-  list(
-    object = class(x),
-    payload = state,
-    constructor = attr(x, "ctor"),
-    package = pkg,
-    version = as.character(pkg_version(pkg))
-  )
-}
-
 #' @export
 c.block <- function(...) {
 
@@ -560,18 +452,8 @@ block_name <- function(x) {
 }
 
 block_ctor <- function(x) {
-
   stopifnot(is_block(x))
-
-  fun <- attr(x, "ctor")
-
-  if (is.function(fun)) {
-    return(fun)
-  }
-
-  pkg <- attr(x, "ctor_pkg")
-
-  get(fun, envir = asNamespace(pkg), mode = "function", inherits = FALSE)
+  attr(x, "ctor")
 }
 
 block_expr_server <- function(x) {
@@ -698,11 +580,14 @@ format.block <- function(x, ...) {
     out <- c(out, "Stateless block")
   }
 
-  if (!is.null(attr(x, "ctor_pkg"))) {
-    ctor <- paste0(attr(x, "ctor_pkg"), "::", attr(x, "ctor"), "()")
-  } else {
+  ctor <- block_ctor(x)
+
+  if (is.null(ctor_name(ctor))) {
     ctor <- "<local function>"
+  } else {
+    ctor <- paste0(ctor_pkg(ctor), "::", ctor_name(ctor), "()")
   }
+
   c(out, paste("Constructor:", ctor))
 }
 
@@ -711,3 +596,8 @@ print.block <- function(x, ...) {
   cat(format(x, ...), sep = "\n")
   invisible(x)
 }
+
+#' @export
+board_options.block <- function(x, ...) {
+  new_board_options()
+}
