@@ -31,8 +31,3 @@ new_static_block <- function(data, ...) {
     ...
   )
 }
-
-#' @export
-as.list.static_block <- function(x, ...) {
-  stop("Cannot serialize upload blocks.")
-}
