@@ -25,7 +25,7 @@ new_parser_block <- function(server, ui, class, ctor = sys.parent(),
 
 #' @export
 block_output.parser_block <- function(x, result, session) {
-  dt_result(result, session)
+  dt_result(result, x, session)
 }
 
 #' @export
@@ -38,3 +38,17 @@ block_ui.parser_block <- function(id, x, ...) {
 is_file <- function(file) {
   stopifnot(is_string(file), file.exists(file))
 }
+
+#' @export
+#' @include utils-dt.R
+block_render_trigger.parser_block <- dt_render_trigger
+
+#' @export
+board_options.parser_block <- function(x, ...) {
+  combine_board_options(
+    new_n_rows_option(...),
+    new_page_size_option(...),
+    new_filter_rows_option(...),
+    NextMethod()
+  )
+}
