@@ -1,17 +1,37 @@
+#' Assertions
+#'
+#' Utility functions, mainly intended for asserting common preconditions are
+#' exported for convenience in dependent packages.
+#'
+#' @param x Object to check
+#'
+#' @return Scalar logical value.
+#'
+#' @rdname assertions
+#' @export
 is_scalar <- function(x) length(x) == 1L
 
+#' @rdname assertions
+#' @export
 is_string <- function(x) {
   is.character(x) && is_scalar(x)
 }
 
+#' @rdname assertions
+#' @export
 is_bool <- function(x) {
-  is_scalar(x) && (identical(x, TRUE) || identical(x, FALSE))
+  is_scalar(x) && (isTRUE(x) || isFALSE(x))
 }
 
+#' @rdname assertions
+#' @export
 is_intish <- function(x) {
   is.integer(x) || (is.numeric(x) && all(x == trunc(x)) && !is.na(x))
 }
 
+#' @param allow_zero Determines whether the value 0 is considered a valid count
+#' @rdname assertions
+#' @export
 is_count <- function(x, allow_zero = TRUE) {
 
   if (!is_scalar(x)) {
@@ -29,12 +49,21 @@ is_count <- function(x, allow_zero = TRUE) {
   }
 }
 
+#' @rdname assertions
+#' @export
 is_number <- function(x) {
   is.numeric(x) && is_scalar(x) && !is.na(x) && !is.nan(x) && is.finite(x)
 }
 
+#' @param ... Silently ignored
+#' @rdname assertions
+#' @export
 not_null <- Negate(is.null)
 
+#' @rdname assertions
+#' @export
+has_length <- function(x) length(x) > 0
+
 is_zero_len <- function(x) {
   length(x) == 0L
 }
@@ -62,15 +91,3 @@ filter_all_zero_len <- function(x) {
 }
 
 filter_empty <- function(x) Filter(Negate(is_empty), x)
-
-expect_null <- function(x) {
-
-  if (!is.null(x)) {
-    abort(
-      paste("Expected `NULL`, but got", paste_enum(class(x)), "instead."),
-      class = "not_null"
-    )
-  }
-
-  invisible(x)
-}
