@@ -22,4 +22,19 @@ test_that("filebrowser block constructor", {
     },
     args = list(x = blk)
   )
+
+  vols <- filebrowser_volumes()
+
+  expect_type(vols, "character")
+  expect_named(vols, "home")
+
+  vols <- filebrowser_volumes(file.path("foo", "bar"))
+
+  expect_type(vols, "character")
+  expect_named(vols, "volume")
+
+  vols <- filebrowser_volumes("foo/bar:foo/baz")
+
+  expect_type(vols, "character")
+  expect_named(vols, c("volume1", "volume2"))
 })
